A list of versions and changes to the project:

- v0.0.6 - Remove setup_requires dependency on pypandoc.
- v0.0.5 - Fix install error when installing from sdist (missing README)
- v0.0.4 - Fix issue with pypandoc usage.
- v0.0.3 - Fixed issue with boolean defaults, allow for type_class and UnsetExceptions.
- v0.0.2 - Fixed issue with ConfigParser lowercasing keys.
- v0.0.1 - Initial commit to GitHub.
